# inspired from:

# https://python-packaging-user-guide.readthedocs.org/en/latest/single_source_version/
# https://github.com/pypa/warehouse/blob/master/warehouse/__about__.py

__title__ = 'sputnik'
__version__ = '0.9.3'
__summary__ = 'Data package manager library'
__uri__ = 'https://github.com/spacy-io/sputnik'
__author__ = 'Henning Peters'
__email__ = 'hp@spacy.io'
__license__ = 'MIT'
